@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2022, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -96,17 +98,6 @@ class Add_instance {
         m_target_instance(target_instance),
         m_options(options) {
     assert(m_cluster_impl);
-
-    // Init progress_style
-    if (m_options.wait_recovery == 0) {
-      m_progress_style = Recovery_progress_style::NOWAIT;
-    } else if (m_options.wait_recovery == 1) {
-      m_progress_style = Recovery_progress_style::NOINFO;
-    } else if (m_options.wait_recovery == 2) {
-      m_progress_style = Recovery_progress_style::TEXTUAL;
-    } else {
-      m_progress_style = Recovery_progress_style::PROGRESSBAR;
-    }
   }
 
   Add_instance(const Add_instance &) = delete;
@@ -151,7 +142,6 @@ class Add_instance {
   std::shared_ptr<mysqlsh::dba::Instance> m_target_instance;
   std::shared_ptr<mysqlsh::dba::Instance> m_primary_instance;
   Add_instance_options m_options;
-  Recovery_progress_style m_progress_style = Recovery_progress_style::TEXTUAL;
   bool m_already_member = false;
   std::string m_comm_stack;
   std::string m_account_host;
