@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -257,7 +259,7 @@ inline constexpr const char kAddInstances[] = "addInstances";
 inline constexpr const char kRemoveInstances[] = "removeInstances";
 inline constexpr const char kRejoinInstances[] = "rejoinInstances";
 inline constexpr const char kWaitRecovery[] = "waitRecovery";
-inline constexpr const char kRecoveryVerbosity[] = "recoveryProgress";
+inline constexpr const char kRecoveryProgress[] = "recoveryProgress";
 inline constexpr const char kLabel[] = "label";
 inline constexpr const char kExtended[] = "extended";
 inline constexpr const char kQueryMembers[] = "queryMembers";
@@ -497,8 +499,7 @@ bool SHCORE_PUBLIC validate_cluster_group_name(
     const mysqlshdk::mysql::IInstance &instance, const std::string &group_name);
 
 bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                              mysqlshdk::null_bool clear_read_only,
-                              bool interactive);
+                              std::optional<bool> clear_read_only);
 
 enum class Instance_rejoinability {
   REJOINABLE,
@@ -518,8 +519,6 @@ bool is_sandbox(const mysqlshdk::mysql::IInstance &instance,
 // AdminAPI interactive handling specific methods
 std::string prompt_cnf_path(const mysqlshdk::mysql::IInstance &instance);
 int prompt_menu(const std::vector<std::string> &options, int defopt);
-bool prompt_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                            bool throw_on_error = false);
 void dump_table(const std::vector<std::string> &column_names,
                 const std::vector<std::string> &column_labels,
                 shcore::Value::Array_type_ref documents);
