@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -152,6 +154,12 @@ void Instance::prepare_session() {
     set_sysvar("collation_connection", std::string("utf8mb4_general_ci"),
                mysqlshdk::mysql::Var_qualifier::SESSION);
 
+  // Make sure that the limit for 'group_concat_max_len' is increased from the
+  // default 1024 to 1GB. There's no "correct" value here, hence no constant for
+  // the variable.
+  set_sysvar("group_concat_max_len", static_cast<int64_t>(1024 * 1024 * 1024),
+             mysqlshdk::mysql::Var_qualifier::SESSION);
+
   // Cache the hostname, port, and UUID to avoid errors accessing this data if
   // the instance fails during an operation.
   get_canonical_address();
