@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -30,6 +32,7 @@
 #include <utility>
 
 #include "modules/mod_utils.h"
+#include "modules/util/common/dump/constants.h"
 #include "modules/util/common/dump/utils.h"
 #include "modules/util/dump/dump_manifest_config.h"
 #include "modules/util/load/load_errors.h"
@@ -50,11 +53,6 @@ namespace {
 
 using Version = mysqlshdk::utils::Version;
 
-const char *k_excluded_users[] = {"mysql.infoschema", "mysql.session",
-                                  "mysql.sys"};
-const char *k_oci_excluded_users[] = {"administrator", "ociadmin", "ocimonitor",
-                                      "ocirpl"};
-
 constexpr auto k_minimum_max_bytes_per_transaction = 4096;
 
 bool is_mds(const Version &version) {
@@ -273,10 +271,10 @@ void Load_dump_options::set_session(
 
   if (m_load_users) {
     // some users are always excluded
-    filters().users().exclude(k_excluded_users);
+    filters().users().exclude(dump::common::k_excluded_users);
 
     if (is_mds()) {
-      filters().users().exclude(k_oci_excluded_users);
+      filters().users().exclude(dump::common::k_mhs_excluded_users);
     }
 
     shcore::Account account;
@@ -286,6 +284,10 @@ void Load_dump_options::set_session(
     filters().users().exclude(std::move(account));
   }
 
+  if (is_mds()) {
+    filters().schemas().exclude(dump::common::k_mhs_excluded_schemas);
+  }
+
   if (m_target_server_version >= Version(8, 0, 27)) {
     // adding indexes in parallel was added in 8.0.27,
     // innodb_parallel_read_threads threads are used during the first stage,
@@ -313,6 +315,11 @@ void Load_dump_options::validate() {
     if (config && config->valid()) {
       if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type() ||
           mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
+        if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type()) {
+          current_console()->print_warning(
+              "Support for PAR Manifest is deprecated and will be removed in a "
+              "future release. Please use a prefix PAR instead.");
+        }
         if (!m_progress_file.has_value()) {
           throw shcore::Exception::argument_error(
               "When using a PAR to load a dump, the progressFile option must "
