@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -71,23 +73,39 @@ void clear_buffer(std::string *buffer) {
   buffer->clear();
 }
 
+std::string_view SHCORE_PUBLIC str_strip_view(std::string_view s,
+                                              std::string_view chars) {
+  auto begin = s.find_first_not_of(chars);
+  if (begin == std::string_view::npos) return {};
+
+  auto end = s.find_last_not_of(chars);
+  return s.substr(begin, end - begin + 1);
+}
+
+std::string_view SHCORE_PUBLIC str_lstrip_view(std::string_view s,
+                                               std::string_view chars) {
+  auto begin = s.find_first_not_of(chars);
+  if (begin == std::string_view::npos) return {};
+  return s.substr(begin);
+}
+
+std::string_view SHCORE_PUBLIC str_rstrip_view(std::string_view s,
+                                               std::string_view chars) {
+  auto end = s.find_last_not_of(chars);
+  if (end == std::string_view::npos) return {};
+  return s.substr(0, end + 1);
+}
+
 std::string str_strip(std::string_view s, std::string_view chars) {
-  size_t begin = s.find_first_not_of(chars);
-  size_t end = s.find_last_not_of(chars);
-  if (begin == std::string::npos) return std::string();
-  return std::string{s.substr(begin, end - begin + 1)};
+  return std::string{str_strip_view(s, chars)};
 }
 
 std::string str_lstrip(std::string_view s, std::string_view chars) {
-  size_t begin = s.find_first_not_of(chars);
-  if (begin == std::string::npos) return std::string();
-  return std::string{s.substr(begin)};
+  return std::string{str_lstrip_view(s, chars)};
 }
 
 std::string str_rstrip(std::string_view s, std::string_view chars) {
-  size_t end = s.find_last_not_of(chars);
-  if (end == std::string::npos) return std::string();
-  return std::string{s.substr(0, end + 1)};
+  return std::string{str_rstrip_view(s, chars)};
 }
 
 std::string str_format(const char *formats, ...) {
